@@ -23,9 +23,9 @@ def files_exist(self):
         .markdownlint.yml
         .github/.dockstore.yml
         .github/CONTRIBUTING.md
-        .github/ISSUE_TEMPLATE/bug_report.md
+        .github/ISSUE_TEMPLATE/bug_report.yml
         .github/ISSUE_TEMPLATE/config.yml
-        .github/ISSUE_TEMPLATE/feature_request.md
+        .github/ISSUE_TEMPLATE/feature_request.yml
         .github/PULL_REQUEST_TEMPLATE.md
         .github/workflows/branch.yml
         .github/workflows/ci.yml
@@ -34,16 +34,16 @@ def files_exist(self):
         [LICENSE, LICENSE.md, LICENCE, LICENCE.md]  # NB: British / American spelling
         assets/email_template.html
         assets/email_template.txt
-        assets/nf-core-PIPELINE_logo.png
+        assets/nf-core-PIPELINE_logo_light.png
         assets/sendmail_template.txt
-        bin/scrape_software_versions.py
         conf/modules.config
         conf/test.config
         conf/test_full.config
         CHANGELOG.md
         CITATIONS.md
         CODE_OF_CONDUCT.md
-        docs/images/nf-core-PIPELINE_logo.png
+        docs/images/nf-core-PIPELINE_logo_light.png
+        docs/images/nf-core-PIPELINE_logo_dark.png
         docs/output.md
         docs/README.md
         docs/usage.md
@@ -52,7 +52,6 @@ def files_exist(self):
         lib/NfcoreTemplate.groovy
         lib/Utils.groovy
         lib/WorkflowMain.groovy
-        modules/local/get_software_versions.nf
         nextflow_schema.json
         nextflow.config
         README.md
@@ -78,6 +77,9 @@ def files_exist(self):
         bin/markdown_to_html.r
         conf/aws.config
         .github/workflows/push_dockerhub.yml
+        .github/ISSUE_TEMPLATE/bug_report.md
+        .github/ISSUE_TEMPLATE/feature_request.md
+        docs/images/nf-core-PIPELINE_logo.png
 
     Files that *should not* be present:
 
@@ -109,9 +111,9 @@ def files_exist(self):
         ["README.md"],
         [os.path.join(".github", ".dockstore.yml")],
         [os.path.join(".github", "CONTRIBUTING.md")],
-        [os.path.join(".github", "ISSUE_TEMPLATE", "bug_report.md")],
+        [os.path.join(".github", "ISSUE_TEMPLATE", "bug_report.yml")],
         [os.path.join(".github", "ISSUE_TEMPLATE", "config.yml")],
-        [os.path.join(".github", "ISSUE_TEMPLATE", "feature_request.md")],
+        [os.path.join(".github", "ISSUE_TEMPLATE", "feature_request.yml")],
         [os.path.join(".github", "PULL_REQUEST_TEMPLATE.md")],
         [os.path.join(".github", "workflows", "branch.yml")],
         [os.path.join(".github", "workflows", "ci.yml")],
@@ -120,12 +122,12 @@ def files_exist(self):
         [os.path.join("assets", "email_template.html")],
         [os.path.join("assets", "email_template.txt")],
         [os.path.join("assets", "sendmail_template.txt")],
-        [os.path.join("assets", f"nf-core-{short_name}_logo.png")],
-        [os.path.join("bin", "scrape_software_versions.py")],
+        [os.path.join("assets", f"nf-core-{short_name}_logo_light.png")],
         [os.path.join("conf", "modules.config")],
         [os.path.join("conf", "test.config")],
         [os.path.join("conf", "test_full.config")],
-        [os.path.join("docs", "images", f"nf-core-{short_name}_logo.png")],
+        [os.path.join("docs", "images", f"nf-core-{short_name}_logo_light.png")],
+        [os.path.join("docs", "images", f"nf-core-{short_name}_logo_dark.png")],
         [os.path.join("docs", "output.md")],
         [os.path.join("docs", "README.md")],
         [os.path.join("docs", "README.md")],
@@ -135,7 +137,6 @@ def files_exist(self):
         [os.path.join("lib", "NfcoreTemplate.groovy")],
         [os.path.join("lib", "Utils.groovy")],
         [os.path.join("lib", "WorkflowMain.groovy")],
-        [os.path.join("modules", "local", "get_software_versions.nf")],
     ]
 
     files_warn = [
@@ -156,6 +157,9 @@ def files_exist(self):
         os.path.join("bin", "markdown_to_html.r"),
         os.path.join("conf", "aws.config"),
         os.path.join(".github", "workflows", "push_dockerhub.yml"),
+        os.path.join(".github", "ISSUE_TEMPLATE", "bug_report.md"),
+        os.path.join(".github", "ISSUE_TEMPLATE", "feature_request.md"),
+        os.path.join("docs", "images", f"nf-core-{short_name}_logo.png"),
     ]
     files_warn_ifexists = [".travis.yml"]
 
