@@ -17,6 +17,7 @@ import time
 import webbrowser
 import yaml
 import copy
+import re
 
 import nf_core.list, nf_core.utils
 
@@ -37,6 +38,7 @@ class PipelineSchema(object):
         self.schema_params = []
         self.input_params = {}
         self.pipeline_params = {}
+        self.invalid_nextflow_config_default_parameters = {}
         self.pipeline_manifest = {}
         self.schema_from_scratch = False
         self.no_prompts = False
@@ -81,7 +83,19 @@ class PipelineSchema(object):
             num_params = self.validate_schema()
             self.get_schema_defaults()
             self.validate_default_params()
-            log.info("[green][✓] Pipeline schema looks valid[/] [dim](found {} params)".format(num_params))
+            if len(self.invalid_nextflow_config_default_parameters) > 0:
+                log.info(
+                    "[red][✗] Invalid default parameters found:\n  --{}\n\nNOTE: Use null in config for no default.".format(
+                        "\n  --".join(
+                            [
+                                f"{param}: {msg}"
+                                for param, msg in self.invalid_nextflow_config_default_parameters.items()
+                            ]
+                        )
+                    )
+                )
+            else:
+                log.info("[green][✓] Pipeline schema looks valid[/] [dim](found {} params)".format(num_params))
         except json.decoder.JSONDecodeError as e:
             error_msg = "[bold red]Could not parse schema JSON:[/] {}".format(e)
             log.error(error_msg)
@@ -114,7 +128,8 @@ class PipelineSchema(object):
 
         # For everything else, an empty string is an empty string
         if isinstance(param["default"], str) and param["default"].strip() == "":
-            return ""
+            param["default"] = ""
+            return param
 
         # Integers
         if param["type"] == "integer":
@@ -206,6 +221,9 @@ class PipelineSchema(object):
         """
         Check that all default parameters in the schema are valid
         Ignores 'required' flag, as required parameters might have no defaults
+
+        Additional check that all parameters have defaults in nextflow.config and that
+        these are valid and adhere to guidelines
         """
         try:
             assert self.schema is not None
@@ -221,7 +239,89 @@ class PipelineSchema(object):
             log.error("[red][✗] Pipeline schema not found")
         except jsonschema.exceptions.ValidationError as e:
             raise AssertionError("Default parameters are invalid: {}".format(e.message))
-        log.info("[green][✓] Default parameters look valid")
+        log.info("[green][✓] Default parameters match schema validation")
+
+        # Make sure every default parameter exists in the nextflow.config and is of correct type
+        if self.pipeline_params == {}:
+            self.get_wf_params()
+
+        # Collect parameters to ignore
+        if "schema_ignore_params" in self.pipeline_params:
+            params_ignore = self.pipeline_params.get("schema_ignore_params", "").strip("\"'").split(",")
+        else:
+            params_ignore = []
+
+        # Go over group keys
+        for group_key, group in schema_no_required["definitions"].items():
+            group_properties = group.get("properties")
+            for param in group_properties:
+                if param in params_ignore:
+                    continue
+                if param in self.pipeline_params:
+                    self.validate_config_default_parameter(param, group_properties[param], self.pipeline_params[param])
+                else:
+                    self.invalid_nextflow_config_default_parameters[param] = "Not in pipeline parameters"
+
+        # Go over ungrouped params if any exist
+        ungrouped_properties = self.schema.get("properties")
+        if ungrouped_properties:
+            for param in ungrouped_properties:
+                if param in params_ignore:
+                    continue
+                if param in self.pipeline_params:
+                    self.validate_config_default_parameter(
+                        param, ungrouped_properties[param], self.pipeline_params[param]
+                    )
+                else:
+                    self.invalid_nextflow_config_default_parameters[param] = "Not in pipeline parameters"
+
+    def validate_config_default_parameter(self, param, schema_param, config_default):
+        """
+        Assure that default parameters in the nextflow.config are correctly set
+        by comparing them to their type in the schema
+        """
+
+        # If we have a default in the schema, check it matches the config
+        if "default" in schema_param and (
+            (schema_param["type"] == "boolean" and str(config_default).lower() != str(schema_param["default"]).lower())
+            and (str(schema_param["default"]) != str(config_default).strip('"').strip("'"))
+        ):
+            # Check that we are not deferring the execution of this parameter in the schema default with squiggly brakcets
+            if schema_param["type"] != "string" or "{" not in schema_param["default"]:
+                self.invalid_nextflow_config_default_parameters[
+                    param
+                ] = f"Schema default (`{schema_param['default']}`) does not match the config default (`{config_default}`)"
+                return
+
+        # if default is null, we're good
+        if config_default == "null":
+            return
+
+        # Check variable types in nextflow.config
+        if schema_param["type"] == "string":
+            if str(config_default) in ["false", "true", "''"]:
+                self.invalid_nextflow_config_default_parameters[
+                    param
+                ] = f"String should not be set to `{config_default}`"
+        if schema_param["type"] == "boolean":
+            if not str(config_default) in ["false", "true"]:
+                self.invalid_nextflow_config_default_parameters[
+                    param
+                ] = f"Booleans should only be true or false, not `{config_default}`"
+        if schema_param["type"] == "integer":
+            try:
+                int(config_default)
+            except ValueError:
+                self.invalid_nextflow_config_default_parameters[
+                    param
+                ] = f"Does not look like an integer: `{config_default}`"
+        if schema_param["type"] == "number":
+            try:
+                float(config_default)
+            except ValueError:
+                self.invalid_nextflow_config_default_parameters[
+                    param
+                ] = f"Does not look like a number (float): `{config_default}`"
 
     def validate_schema(self, schema=None):
         """
@@ -536,18 +636,13 @@ class PipelineSchema(object):
         if p_val == "null":
             p_val = None
 
-        # NB: Only test "True" for booleans, as it is very common to initialise
-        # an empty param as false when really we expect a string at a later date..
-        if p_val == "True":
-            p_val = True
+        # Booleans
+        if p_val == "True" or p_val == "False":
+            p_val = p_val == "True"  # Convert to bool
             p_type = "boolean"
 
         p_schema = {"type": p_type, "default": p_val}
 
-        # Assume that false and empty strings shouldn't be a default
-        if p_val == "false" or p_val == "" or p_val is None:
-            del p_schema["default"]
-
         return p_schema
 
     def launch_web_builder(self):
